; HTML5 Button GUI demo for all size Android smartphones and tablets
; Requires Android OS 4.2.2+, and Csound6[.05].apk or higher
;   Downloadable from
; http://sourceforge.net/projects/csound/files/csound6/Csound6.05/
; or http://sourceforge.net/projects/csound/files/csound6/Csound6.06/ 
;   (as CsoundApplication-release.apk)
; Android OS < 5.0 requires the 6.05 download
; No Csound code included
; Enhanced button code is more complex, and responds to "touch up" as well as "touch down"; useful for "notes" and other "gate" events
;    Surprisingly, it exhibits considerably less latency than simple triggers.

; Suggestion: place all HTML outside Csound code at beginning or end of .csd.
; Doing so will happily eliminate it from Csound console output

<html>
<head>
<style type="text/css">

/* eliminates accidental text selection by user in performance */
.noselect {
        -webkit-user-select: none;
}

/* text in buttons is centered */
table td {
	text-align: center;
}

/* buttons are full "touch down/touch up"; they send Csound a 1 upon touch down, and a 0 at touch up */
.buttons {
        width: 80%; /* 100% or less, horizontally centered */
}        
.buttons td {
        background-color: cadetblue; /* user choice */
}

</style>

</head>
<body>

<!-- enclose entire body within a single <div> tag
     so that all text is protected against accidental selection --!>
<div class="noselect">

<!-- avoid headline fonts; they take up valuable vertical space --!>

<big><big><big><b>HTML5 BUTTON GUI</b></big></big></big><br>
<br><br>

<!-- table columns center and auto-align, & adjust to accommodate maximum number of buttons --!>
<table class="buttons" style="margin: auto">
<tr>
<!-- # of maximum characters per label depends on # of buttons in row and % of screen width specified -->
<!-- # of characters should be the same for each button per row --!>
<!-- Note: button is only clickable in text area --!>
<!-- text area can be elongated by adding spaces and non-blanking spaces [&nbsp:]; avoid spaces in mid-text --!>
<td>
<button class="butt_height" id="butt1"> Butt1 </button>
</td>
<td>
<button class="butt_height" id="butt2"> Butt2 </button>
</td>
<td>
<button class="butt_height" id="butt3"> Butt3 </button>
</td>
<td>
<!-- with buttons, longer strings just expand text (clickable) area,
     potentially making buttons unequal in size; neither is a good idea --!>
<button class="butt_height" id="butt4">Button4</button>
</td>
</tr>
<tr>
<td>
<!-- multi-line labels OK; keep # of chars in the longest line the same --!>
<button class="butt_height" id="butt5">Button<br>5</button>
</td>
<td>
<button class="butt_height" id="butt6">Button<br>6.0</button>
</td>
<td>
<button class="butt_height" id="butt7">Button<br>7777</button>
</td>
</tr>
</table>

<script>

/* adjust button height (% of screen) here */
var button_height_fraction = 0.22;

var screen_height = Math.max(document.documentElement.clientHeight, window.innerHeight || 0);
var screen_width = Math.max(document.documentElement.clientWidth, window.innerWidth || 0);
var elements2 = document.getElementsByClassName("butt_height");
Array.prototype.forEach.call(elements2, function(element) {
	element.setAttribute("style", "height: "+ screen_height * button_height_fraction +"px;");
});

/* Trigger buttons: 30ms wait before turning trigger off */
function wait() {
        var ms = 30;  
        ms += new Date().getTime();        
        while (new Date() < ms){};
        return;
}

/* Csound receives on: chnget "butt1" */
/* for Android OS < 5.0 use channel "but1", or any name except "butt1" */ 
butt1.addEventListener("touchstart", startTouch1);
butt1.addEventListener("touchend", stopTouch1);
function startTouch1(event) {
	event.preventDefault();
	csound.setControlChannel('butt1', 1);
}
function stopTouch1(event) {
	event.preventDefault();
	csound.setControlChannel('butt1', 0);
}

/* Csound receives on: chnget "butt2" */
/* for Android OS < 5.0 use channel *name* "but2", or any name except "butt2" */ 
butt2.addEventListener("touchstart", startTouch2);
butt2.addEventListener("touchend", stopTouch2);
function startTouch2(event) {
	event.preventDefault();
	csound.setControlChannel('butt2', 1);
}
function stopTouch2(event) {
	event.preventDefault();
	csound.setControlChannel('butt2', 0);
}

/* Csound receives on: chnget "butt3" */
/* for Android OS < 5.0 use channel *name* "but3", or any name except "butt3" */ 
butt3.addEventListener("touchstart", startTouch3);
butt3.addEventListener("touchend", stopTouch3);
function startTouch3(event) {
	event.preventDefault();
	csound.setControlChannel('butt3', 1);
}
function stopTouch3(event) {
	event.preventDefault();
	csound.setControlChannel('butt3', 0);
}

/* Csound receives on: chnget "butt4" */
/* for Android OS < 5.0 use channel *name* "but4", or any name except "butt4" */ 
butt4.addEventListener("touchstart", startTouch4);
butt4.addEventListener("touchend", stopTouch4);
function startTouch4(event) {
	event.preventDefault();
	csound.setControlChannel('butt4', 1);
}
function stopTouch4(event) {
	event.preventDefault();
	csound.setControlChannel('butt4', 0);
}

/* Csound receives on: chnget "butt5" */
/* for Android OS < 5.0 use channel *name* "but5", or any name except "butt5" */ 
butt5.addEventListener("touchstart", startTouch5);
butt5.addEventListener("touchend", stopTouch5);
function startTouch5(event) {
	event.preventDefault();
	csound.setControlChannel('butt5', 1);
}
function stopTouch5(event) {
	event.preventDefault();
	csound.setControlChannel('butt5', 0);
}

/* Csound receives on: chnget "butt6" */
/* Only channel names "butt1-5" are illegal for Android OS < 5.0 */
function butt6() {
butt6.addEventListener("touchstart", startTouch6);
butt6.addEventListener("touchend", stopTouch6);
function startTouch6(event) {
	event.preventDefault();
	csound.setControlChannel('butt6', 1);
}
function stopTouch6(event) {
	event.preventDefault();
	csound.setControlChannel('butt6', 0);
}

/* Csound receives on: chnget "butt7" */
butt7.addEventListener("touchstart", startTouch7);
butt7.addEventListener("touchend", stopTouch7);
function startTouch7(event) {
	event.preventDefault();
	csound.setControlChannel('butt7', 1);
}
function stopTouch7(event) {
	event.preventDefault();
	csound.setControlChannel('butt7', 0);
}

</script>

</div>
</body>
</html>